@@ -1,12 +1,10 @@
 package Encode::JP::Mobile::Vodafone;
 use strict;
 use base qw(Encode::Encoding);
-__PACKAGE__->Define(qw(x-sjis-vodafone));
+__PACKAGE__->Define(qw(x-sjis-vodafone-raw));
 
 use Encode::Alias;
-define_alias('x-sjis-softbank' => 'x-sjis-vodafone');
-define_alias('shift_jis-softbank' => 'x-sjis-softbank');
-define_alias('shift_jis-vodafone' => 'x-sjis-vodafone');
+define_alias('x-sjis-softbank-raw' => 'x-sjis-vodafone-raw');
 
 # G! => E001, G" => E002, G# => E003 ...
 # E! => E101, F! => E201, O! => E301, P! => E401, Q! => E501
@@ -31,6 +29,7 @@ sub decode($$;$) {
 sub encode($$;$) {
     my($self, $str, $check) = @_;
     my $res = '';
+    $str =~ tr/\x{301C}/\x{FF5E}/; # ad-hoc solution for  FULLWIDTH TILDE Problem
     $str =~ s{($InRange+)|($OutRange+)}{
         my $in = defined $1;
         my $m  = $in ? $1 : $2;
@@ -51,6 +50,7 @@ sub _encode_vodafone {
         my $high = ord($str) & 0xEF00;
         my $low  = ord($str) & 0x00FF;
         if ($buf ne $high) {
+            $res .= "\x0f\x1b\x24" unless $buf eq '';
             $res .= $HighBitToChar{$high};
         }
         $res .= chr($low+32);
